From bippy-c9c4e1df01b2 Mon Sep 17 00:00:00 2001
From: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
To: <linux-cve-announce@vger.kernel.org>
Reply-to: <cve@kernel.org>, <linux-kernel@vger.kernel.org>
Subject: CVE-2024-37021: fpga: manager: add owner module and take its refcount

Description
===========

In the Linux kernel, the following vulnerability has been resolved:

fpga: manager: add owner module and take its refcount

The current implementation of the fpga manager assumes that the low-level
module registers a driver for the parent device and uses its owner pointer
to take the module's refcount. This approach is problematic since it can
lead to a null pointer dereference while attempting to get the manager if
the parent device does not have a driver.

To address this problem, add a module owner pointer to the fpga_manager
struct and use it to take the module's refcount. Modify the functions for
registering the manager to take an additional owner module parameter and
rename them to avoid conflicts. Use the old function names for helper
macros that automatically set the module that registers the manager as the
owner. This ensures compatibility with existing low-level control modules
and reduces the chances of registering a manager without setting the owner.

Also, update the documentation to keep it consistent with the new interface
for registering an fpga manager.

Other changes: opportunistically move put_device() from __fpga_mgr_get() to
fpga_mgr_get() and of_fpga_mgr_get() to improve code clarity since the
manager device is taken in these functions.

The Linux kernel CVE team has assigned CVE-2024-37021 to this issue.


Affected and fixed versions
===========================

	Issue introduced in 4.4 with commit 654ba4cc0f3e and fixed in 6.6.33 with commit 2da62a139a62
	Issue introduced in 4.4 with commit 654ba4cc0f3e and fixed in 6.9.4 with commit 62ac496a01c9
	Issue introduced in 4.4 with commit 654ba4cc0f3e and fixed in 6.10 with commit 4d4d2d434685

Please see https://www.kernel.org for a full list of currently supported
kernel versions by the kernel community.

Unaffected versions might change over time as fixes are backported to
older supported kernel versions.  The official CVE entry at
	https://cve.org/CVERecord/?id=CVE-2024-37021
will be updated if fixes are backported, please check that for the most
up to date information about this issue.


Affected files
==============

The file(s) affected by this issue are:
	Documentation/driver-api/fpga/fpga-mgr.rst
	drivers/fpga/fpga-mgr.c
	include/linux/fpga/fpga-mgr.h


Mitigation
==========

The Linux kernel CVE team recommends that you update to the latest
stable kernel version for this, and many other bugfixes.  Individual
changes are never tested alone, but rather are part of a larger kernel
release.  Cherry-picking individual commits is not recommended or
supported by the Linux kernel community at all.  If however, updating to
the latest release is impossible, the individual changes to resolve this
issue can be found at these commits:
	https://git.kernel.org/stable/c/2da62a139a6221a345db4eb9f4f1c4b0937c89ad
	https://git.kernel.org/stable/c/62ac496a01c9337a11362cea427038ba621ca9eb
	https://git.kernel.org/stable/c/4d4d2d4346857bf778fafaa97d6f76bb1663e3c9
